summaryrefslogtreecommitdiff
path: root/netci.groovy
diff options
context:
space:
mode:
authorjashook <jashoo@microsoft.com>2016-02-29 17:06:40 -0800
committerjashook <jashoo@microsoft.com>2016-03-02 10:02:47 -0800
commitf3902d06a64eba17de66407b854d5940107a0ff6 (patch)
tree8cdc87e655f2a0049af5ae3fea8147f95eba1f65 /netci.groovy
parenta05632c70d588bed5099a67f032ad510c0164aaa (diff)
downloadcoreclr-f3902d06a64eba17de66407b854d5940107a0ff6.tar.gz
coreclr-f3902d06a64eba17de66407b854d5940107a0ff6.tar.bz2
coreclr-f3902d06a64eba17de66407b854d5940107a0ff6.zip
Small changes to netci to enable arm64 testing.
Diffstat (limited to 'netci.groovy')
-rw-r--r--netci.groovy6
1 files changed, 4 insertions, 2 deletions
diff --git a/netci.groovy b/netci.groovy
index 38b3389e42..b743734c19 100644
--- a/netci.groovy
+++ b/netci.groovy
@@ -797,7 +797,9 @@ combinedScenarios.each { scenario ->
case 'arm64':
assert scenario == 'default'
buildCommands += "build.cmd ${lowerConfiguration} ${architecture} skiptestbuild /toolset_dir C:\\ats"
- // Add archival. No xunit results for x64 windows
+ buildCommands += "C:\\arm64PostBuild.cmd %WORKSPACE% ${architecture} ${lowerConfiguration}"
+
+ // Add archival. No xunit results for arm64 windows
Utilities.addArchival(newJob, "bin/Product/**")
break
default:
@@ -1098,4 +1100,4 @@ build(params + [CORECLR_BUILD: coreclrBuildJob.build.number,
} // os
} // architecture
} // isPR
-} // scenario \ No newline at end of file
+} // scenario